"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const chai_1 = require("chai");
const trie_1 = require("./trie");
const importExport_1 = require("./importExport");
const Rx = require("rxjs/Rx");
const fs = require("fs-extra");
const path = require("path");
const zlib = require("zlib");
const pathToDict = path.dirname(require.resolve('cspell-dict-es-es'));
const trieFileContents = fs.readFile(path.join(pathToDict, 'Spanish.trie.gz'))
    .then(buffer => zlib.gunzipSync(buffer))
    .then(buffer => buffer.toString('UTF-8'));
const trieLines = Rx.Observable
    .fromPromise(trieFileContents.then(trieFileContents => trieFileContents.split('\n')))
    .flatMap(a => a);
const trieNode = importExport_1.importTrieRx(trieLines).take(1).toPromise();
const trie = trieNode.then(node => new trie_1.Trie(node));
describe('Validate Spanish Suggestions', () => {
    it('Tests suggestions', () => {
        return trie.then(trie => {
            // cspell:ignore Carmjen
            const results = trie.suggestWithCost('carmjen', 10);
            // console.log(JSON.stringify(results));
            const suggestions = results.map(s => s.word);
            chai_1.expect(suggestions).to.contain('carmen');
            chai_1.expect(suggestions[0]).to.be.equal('carmen');
        });
    });
});
//# sourceMappingURL=suggest-es.test.js.map